// GotoLineDlg.h
// (c) 2003-2004 exeal

#ifndef _GOTO_LINE_DLG_H_
#define _GOTO_LINE_DLG_H_

#include "..\Manah\Dialog.h"


// CGotoLineDlg class definition
/////////////////////////////////////////////////////////////////////////////

namespace Alpha {

class CAlphaApp;

///	[wsֈړ] _CAO
class CGotoLineDlg : public Manah::Windows::Controls::CDialog {
	// f[^o
public:
	bool				m_bLineUnit;		// _ŝƂ true
	bool				m_bSaveSelection;	// IێƂ true
	bool				m_bAutoClose;		// Ƀ_CAOƂ true
	unsigned long		m_iLineNumber;		// sԍ
private:
	const CAlphaApp&	m_app;

	// RXgN^
public:
	CGotoLineDlg(const CAlphaApp& app);

	// bZ[Wnh
protected:
	void	OnActivate(UINT nState, HWND hwndPrevious, bool bMinimized);	// WM_ACTIVATE
	void	OnClose();														// WM_CLOSE
	bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);				// WM_INITDIALOG
	void	OnOK();															// IDOK
};

}

#endif /* _GOTO_LINE_DLG_H_ */

/* [EOF] */